%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Funcin para leer los resultados de los sensores IR de un mdulo sensor
% AX-S1 con ID=100. Devuelve el valor de los flags ya en binario y muestra,
% si se desea los resultados por pantalla. 
% Por defecto lee en modo normal con umbral de 125
%
%       SINTAXIS:   flag=LecturaIR([umbral,mostrar])
%                   [flag,valores]=LecturaIR([umbral,mostrar])
%
%       INPUT (opcionales): 
%          umbral: valor entre 0 y 255 para fijar umbral del flag. De 1 a
%                  255 fija valor en en modo normal. Si vale 0 se toma modo
%                  precisin. Por defecto modo normal a 125.
%          mostrar: 0 (muestra resultados por pantalla, por defecto)
%                   1 (no muestra resultados por pantalla)
%
%       OUTPUT: 
%          flag: valor pasado a binario dado por los sensores IR del AX-S1
%                valores(opcional): devuelve los valores ledos por los sensores
%                en forma de vector [derecha, centro, izquierda].
%                Devuelve -1 si algun error
%              
%
%                                                            
%                                                Santiago Rodrguez Palma
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [flag,varargout]=LecturaIR(varargin)

%% Inicializar salida
flag=-1;        % Indica que ha habido algn error en la funcin
valores=-1*ones(3,1);
if( libisloaded('dynamixel') )   
    %% Fijar modo de funcionamiento (umbral y precision/no precision).
    if(nargin==1 || nargin==2)           % Especificado por usuario
        umbral=varargin{1};
        if (umbral>=0 && umbral<=255)       % Fijar umbrar para modo normal
            calllib('dynamixel','dxl_write_byte',100,52,umbral);
                                            % Poner en modo precisin
            calllib('dynamixel','dxl_write_byte',100,52,0); 
        else
            fprintf('\nERROR en LecturaIR: el primer argumento debe ser un');
            fprintf('\n numero (0-255)\n\n');
            return
        end
        if(nargin==2)
            mostrar=varargin{2};
        else
            mostrar=0;      % Por defecto muestra resultados por pantalla
        end
    else                    % Por defecto si no hay argumentos de entrada
        calllib('dynamixel','dxl_write_byte',100,52,125)

        mostrar=0;
    end
    
    %% Lectura de sensores (devuelve cadena de caracteres)
    flag=dec2bin( calllib('dynamixel','dxl_read_byte',100,32) );    
    derecha=calllib('dynamixel','dxl_read_byte',100,28);
    centro=calllib('dynamixel','dxl_read_byte',100,27);
    izquierda=calllib('dynamixel','dxl_read_byte',100,26);
    
    %% Salida/s de la funcin
    if(nargout==2)
        varargout(1)={[derecha, centro, izquierda ]};
    end
    
    %% Resultados por pantalla si procede
    if(mostrar==0) % Se muestran resultados por pantalla
        if(umbral>0)
            fprintf('\n********  MODO NORMAL  ********  ');
        else
            fprintf('\n******  MODO PRECISIN  ******  ');
        end
        fprintf('\n FLAG    DER   CENTRO    IZQ\n')
        fprintf('------  ------ -------  ---------\n')
        fprintf('  %s  %5d  %7d %7d\n\n',flag,derecha,centro,izquierda);
    end
    
else
    fprintf('\nERROR en LecturaIR: librera Dynamixel no cargada\n\n');
end    